@@ -10,9 +10,10 @@ import collections.abc
 import shutil
 import math
 import numpy as np
+import tqdm
 
 
-__version__ = '0.9.0'
+__version__ = '0.10.0'
 
 
 def FlattenList_detail(data):
@@ -105,10 +106,18 @@ Dump data (as ``list`` or ``dict``) to YAML file.
 Unless ``force = True`` the function prompts before overwriting an existing file.
     '''
 
+    dirname = os.path.dirname(filename)
+
     if not force:
         if os.path.isfile(filename):
             if not click.confirm('Overwrite "{0:s}"?'.format(filename)):
                 sys.exit(1)
+        elif not os.path.isdir(dirname) and len(dirname) > 0:
+            if not click.confirm('Create "{0:s}"?'.format(os.path.dirname(filename))):
+                sys.exit(1)
+
+    if not os.path.isdir(dirname) and len(dirname) > 0:
+        os.makedirs(os.path.dirname(filename))
 
     with open(filename, 'w') as file:
         ret = yaml.dump(data, file)
@@ -259,7 +268,7 @@ Get SHA256 for a file.
         return h.hexdigest()
 
 
-def GetChecksums(filepaths, yaml_hostinfo=None, hybrid=False):
+def GetChecksums(filepaths, yaml_hostinfo=None, hybrid=False, progress=False):
     r'''
 Compute the checksums for ``filepaths``.
 
@@ -279,6 +288,9 @@ Compute the checksums for ``filepaths``.
         If ``True``, the function first tries to read from ``yaml_hostinfo``, and then
         computes missing items on the fly.
 
+    **progress** ([``False``] | ``True``)
+        If ``True`` a progress-bar is printed.
+
 :returns:
 
     (``<list<str>>``)
@@ -293,7 +305,7 @@ Compute the checksums for ``filepaths``.
 
     if not yaml_hostinfo:
 
-        for i in range(n):
+        for i in tqdm.trange(n, disable=not progress):
             if os.path.isfile(filepaths[i]):
                 ret[i] = GetSHA256(filepaths[i])
 
@@ -304,16 +316,23 @@ Compute the checksums for ``filepaths``.
     data = YamlRead(yaml_hostinfo)
     files = data['files']
     prefix = data['prefix']
-    checksum = data['checksum']
-    paths = PrefixPaths(prefix, files)
+    check_sums = data['checksum']
+    check_paths = PrefixPaths(prefix, files)
 
-    for i in range(n):
-        if filepaths[i] in paths:
-            j = np.argwhere([path == filepaths[i] for path in paths]).ravel()[0]
-            ret[i] = checksum[j]
+    sorter = np.argsort(filepaths)
+    source_paths = np.array(filepaths)[sorter]
+
+    i = np.argsort(check_paths)
+    check_paths = np.array(check_paths)[i]
+    check_sums = np.array(check_sums)[i]
+
+    test = np.in1d(source_paths, check_paths)
+    idx = np.searchsorted(check_paths, source_paths)
+    ret = np.where(test, check_sums[idx], None)
+    ret = list(ret[sorter])
 
     if hybrid:
-        for i in range(n):
+        for i in tqdm.trange(n, disable=not progress):
             if ret[i] is None:
                 if os.path.isfile(filepaths[i]):
                     ret[i] = GetSHA256(filepaths[i])
@@ -329,6 +348,8 @@ def ShelephantCopy(
     checksum = False,
     quiet = False,
     force = False,
+    print_details = True,
+    print_summary = True,
     theme_name = 'none',
     yaml_hostinfo_src = None,
     yaml_hostinfo_dest = None):
@@ -360,6 +381,12 @@ Copy/move files.
     **force** ([``False``] | ``True``)
         Continue without prompt.
 
+    **print_details** ([``True``] | ``False``)
+        Print copy details.
+
+    **print_summary** ([``True``] | ``False``)
+        Print copy summary.
+
     **theme_name** ([``'none'``] | ``<str>``)
         The name of the color-theme. See ``Theme``.
 
@@ -402,43 +429,51 @@ Copy/move files.
     ncreate = sum(create)
     noverwrite = sum(overwrite)
     nskip = sum(skip)
+    pcreate = not (noverwrite > 0 and ncreate > 100)
     pskip = nskip <= 100
-    skip_meesage = ' (not printed)' if not pskip else ''
+    pcreate_message = ' (not printed)' if not pcreate else ''
+    pskip_message = ' (not printed)' if not pskip else ''
+
+    overview = []
+    if ncreate > 0:
+        overview += [String('create (->): {0:d}{1:s}'.format(ncreate, pcreate_message), color=theme['new']).format()]
+    if noverwrite > 0:
+        overview += [String('overwrite (=>): {0:d}'.format(noverwrite), color=theme['overwrite']).format()]
+    if nskip > 0:
+        overview += [String('skip (==): {0:d}{1:s}'.format(nskip, pskip_message), color=theme['skip']).format()]
 
     summary = []
     summary += ['- from dir. : ' + os.path.normpath(src_dir)]
     summary += ['- to dir.   : ' + os.path.normpath(dest_dir)]
-    summary += ['- ' + ', '.join([
-        String('create (->): {0:d}'.format(ncreate), color=theme['new']).format(),
-        String('overwrite (=>): {0:d}'.format(noverwrite), color=theme['overwrite']).format(),
-        String('skip (==): {0:d}{1:s}'.format(nskip, skip_meesage), color=theme['skip']).format()])]
+    summary += ['- ' + ', '.join(overview)]
 
-    if ncreate + noverwrite <= 100:
+    if ncreate + noverwrite <= 100 and print_summary:
         print('-----')
         print('\n'.join(summary))
         print('-----')
 
-    for i in range(n):
-        if create[i]:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['bright']).format(),
-                String('->', color=theme['bright']).format(),
-                String(files[i], color=theme['new']).format()
-            ))
-        elif skip[i] and pskip:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['skip']).format(),
-                String('==', color=theme['skip']).format(),
-                String(files[i], color=theme['skip']).format()
-            ))
-        elif overwrite[i]:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['bright']).format(),
-                String('=>', color=theme['bright']).format(),
-                String(files[i], color=theme['overwrite']).format()
-            ))
+    if print_details:
+        for i in range(n):
+            if create[i] and pcreate:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['bright']).format(),
+                    String('->', color=theme['bright']).format(),
+                    String(files[i], color=theme['new']).format()
+                ))
+            elif skip[i] and pskip:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['skip']).format(),
+                    String('==', color=theme['skip']).format(),
+                    String(files[i], color=theme['skip']).format()
+                ))
+            elif overwrite[i]:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['bright']).format(),
+                    String('=>', color=theme['bright']).format(),
+                    String(files[i], color=theme['overwrite']).format()
+                ))
 
-    if ncreate + noverwrite > 100:
+    if ncreate + noverwrite > 100 and print_summary:
         print('-----')
         print('\n'.join(summary))
         print('-----')
@@ -450,16 +485,10 @@ Copy/move files.
         if not click.confirm('Proceed?'):
             return 1
 
-    ncp = n - nskip
-    l = int(math.log10(ncp) + 1)
-    fmt = '({0:' + str(l) + 'd}/' + ('{0:' + str(l) + 'd}').format(ncp) + ') {1:s}'
-    j = 0
-
-    for i in range(n):
+    pbar = tqdm.trange(n, disable=quiet, total=ncreate + noverwrite)
+    for i in pbar:
         if not skip[i]:
-            if not quiet:
-                j += 1
-                print(fmt.format(j, files[i]))
+            pbar.set_description(files[i])
             copy_function(src[i], dest[i])
 
 
@@ -472,6 +501,8 @@ def ShelephantCopySSH(
     checksum = False,
     quiet = False,
     force = False,
+    print_details = True,
+    print_summary = True,
     verbose = False,
     theme_name = 'none',
     yaml_hostinfo_src = None,
@@ -507,6 +538,12 @@ Send/get files.
     **force** ([``False``] | ``True``)
         Continue without prompt.
 
+    **print_details** ([``True``] | ``False``)
+        Print copy details.
+
+    **print_summary** ([``True``] | ``False``)
+        Print copy summary.
+
     **verbose** ([``False``] | ``True``)
         Verbose all operations.
 
@@ -557,8 +594,18 @@ Send/get files.
     ncreate = sum(create)
     noverwrite = sum(overwrite)
     nskip = sum(skip)
+    pcreate = not (noverwrite > 0 and ncreate > 100)
     pskip = nskip <= 100
-    skip_meesage = ' (not printed)' if not pskip else ''
+    pcreate_message = ' (not printed)' if not pcreate else ''
+    pskip_message = ' (not printed)' if not pskip else ''
+
+    overview = []
+    if ncreate > 0:
+        overview += [String('create (->): {0:d}{1:s}'.format(ncreate, pcreate_message), color=theme['new']).format()]
+    if noverwrite > 0:
+        overview += [String('overwrite (=>): {0:d}'.format(noverwrite), color=theme['overwrite']).format()]
+    if nskip > 0:
+        overview += [String('skip (==): {0:d}{1:s}'.format(nskip, pskip_message), color=theme['skip']).format()]
 
     summary = []
     if copy_function == CopyToRemote:
@@ -569,37 +616,35 @@ Send/get files.
         summary += ['- from host          : ' + host]
         summary += ['- from dir. (remote) : ' + os.path.normpath(src_dir)]
         summary += ['- to dir. (local)    : ' + os.path.normpath(dest_dir)]
-    summary += ['- ' + ', '.join([
-        String('create (->): {0:d}'.format(ncreate), color=theme['new']).format(),
-        String('overwrite (=>): {0:d}'.format(noverwrite), color=theme['overwrite']).format(),
-        String('skip (==): {0:d}{1:s}'.format(nskip, skip_meesage), color=theme['skip']).format()])]
+    summary += ['- ' + ', '.join(overview)]
 
-    if ncreate + noverwrite <= 100:
+    if ncreate + noverwrite <= 100 and print_summary:
         print('-----')
         print('\n'.join(summary))
         print('-----')
 
-    for i in range(n):
-        if create[i]:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['bright']).format(),
-                String('->', color=theme['bright']).format(),
-                String(files[i], color=theme['new']).format()
-            ))
-        elif skip[i] and pskip:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['skip']).format(),
-                String('==', color=theme['skip']).format(),
-                String(files[i], color=theme['skip']).format()
-            ))
-        elif overwrite[i]:
-            print('{0:s} {1:s} {2:s}'.format(
-                String(files[i], width=l, color=theme['bright']).format(),
-                String('=>', color=theme['bright']).format(),
-                String(files[i], color=theme['overwrite']).format()
-            ))
+    if print_details:
+        for i in range(n):
+            if create[i] and pcreate:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['bright']).format(),
+                    String('->', color=theme['bright']).format(),
+                    String(files[i], color=theme['new']).format()
+                ))
+            elif skip[i] and pskip:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['skip']).format(),
+                    String('==', color=theme['skip']).format(),
+                    String(files[i], color=theme['skip']).format()
+                ))
+            elif overwrite[i]:
+                print('{0:s} {1:s} {2:s}'.format(
+                    String(files[i], width=l, color=theme['bright']).format(),
+                    String('=>', color=theme['bright']).format(),
+                    String(files[i], color=theme['overwrite']).format()
+                ))
 
-    if ncreate + noverwrite > 100:
+    if ncreate + noverwrite > 100 and print_summary:
         print('-----')
         print('\n'.join(summary))
         print('-----')
@@ -611,16 +656,10 @@ Send/get files.
         if not click.confirm('Proceed?'):
             return 1
 
-    ncp = n - sum(skip)
-    l = int(math.log10(ncp) + 1)
-    fmt = '({0:' + str(l) + 'd}/' + ('{0:' + str(l) + 'd}').format(ncp) + ') {1:s}'
-    j = 0
-
-    for i in range(n):
+    pbar = tqdm.trange(n, disable=quiet, total=ncreate + noverwrite)
+    for i in pbar:
         if not skip[i]:
-            if not quiet:
-                j += 1
-                print(fmt.format(j, files[i]))
+            pbar.set_description(files[i])
             copy_function(host, src[i], dest[i], verbose)
 
 
