@@ -15,6 +15,8 @@ Options:
     -k, --key=N     Path in the YAML-file, separated by "/". [default: /]
         --colors=M  Select color scheme from: none, dark. [default: dark]
     -q, --quiet     Do not print progress.
+    -s, --summary   Only print summary.
+        --details   Force print of details.
     -f, --force     Move without prompt.
     -h, --help      Show help.
         --version   Show version.
@@ -46,6 +48,8 @@ def main():
         checksum = args['--checksum'],
         quiet = args['--quiet'],
         force = args['--force'],
+        print_details = not (args['--force'] or args['--summary']) or args['--details'],
+        print_summary = not args['--force'] or args['--summary'],
         theme_name = args['--colors'].lower())
 
 
