@@ -3,8 +3,12 @@
     The filenames are assumed either absolute, or relative to the input YAML-file.
 
 Usage:
+    shelephant_rm [options]
     shelephant_rm [options] <input.yaml>
 
+Argument:
+    YAML-file with filenames. Default: shelephant_dump.yaml
+
 Options:
     -k, --key=N     Path in the YAML-file, separated by "/". [default: /]
     -f, --force     Remove without prompt.
@@ -19,16 +23,17 @@ import click
 import os
 
 from .. import __version__
-from . import YamlGetItem
-from . import PrefixPaths
+from .. import YamlGetItem
+from .. import PrefixPaths
 
 
 def main():
 
     args = docopt.docopt(__doc__, version=__version__)
     key = list(filter(None, args['--key'].split('/')))
-    files = YamlGetItem(args['<input.yaml>'], key)
-    prefix = os.path.dirname(args['<input.yaml>'])
+    source = args['<input.yaml>'] if args['<input.yaml>'] else 'shelephant_dump.yaml'
+    files = YamlGetItem(source, key)
+    prefix = os.path.dirname(source)
     files = PrefixPaths(prefix, files)
 
     if len(files) == 0:
