@@ -15,6 +15,8 @@ Options:
     -q, --quiet         Do not print progress.
     -f, --force         Force overwrite of all existing (but not matching) files.
     -l, --local=N       Add local 'host' information to use precomputed checksums.
+    -s, --summary       Only print summary.
+        --details       Force print of details.
         --verbose       Verbose all commands.
     -h, --help          Show help.
         --version       Show version.
@@ -58,6 +60,8 @@ def main():
             checksum = 'checksum' in data,
             quiet = args['--quiet'],
             force = args['--force'],
+            print_details = not (args['--force'] or args['--summary']) or args['--details'],
+            print_summary = not args['--force'] or args['--summary'],
             theme_name = args['--colors'].lower(),
             yaml_hostinfo_src = args['--local'],
             yaml_hostinfo_dest = hostinfo)
@@ -73,6 +77,8 @@ def main():
             checksum = 'checksum' in data,
             quiet = args['--quiet'],
             force = args['--force'],
+            print_details = not (args['--force'] or args['--summary']) or args['--details'],
+            print_summary = not args['--force'] or args['--summary'],
             verbose = args['--verbose'],
             theme_name = args['--colors'].lower(),
             yaml_hostinfo_src = args['--local'],
